from xaal.schemas import devices

from zwave_js_server.model.node import Node
from zwave_js_server.model.value import Value
from zwave_js_server.event import Event

from logging import getLogger

from .cmdclass import COMMAND_CLASS

import pdb


logger = getLogger(__name__)


def get_property_id(value: Value):
    if value.property_ in ["value", "currentValue", "targetValue"]:
        return value.property_key_name
    return "--" + str(value.property_name)


def dump_value(value: Value):
    print(f"[{value}] {'0x%x'%value.command_class} {value.endpoint} {get_property_id(value)} => {value.value}")


def build_devices(node: Node):
    config = node.device_config
    logger.info(f"{node.node_id} {config.manufacturer}/{config.label} ")
    # node.on("value updated", self.value_updated)
    # pdb.set_trace()
    for k in node.values:
        value = node.values.get(k)
        assert value
        if value.command_class == COMMAND_CLASS.SWITCH_BINARY.value and value.property_ == 'currentValue':
            dump_value(value)
        if value.command_class == COMMAND_CLASS.METER.value and value.property_ == 'value':
            dump_value(value)

    # if node.node_id == 5:
    # pdb.set_trace()


class ZwaveDevice(object):
    def __init__(self, node: Node):
        self.node = node

    def setup(self):
        pass

    def update(self, event: Event):
        pass


class PowerRelay(ZwaveDevice):
    def __init__(self, node):
        super().__init__(node)
        self.dev = devices.powerrelay()


class PowerMeter(ZwaveDevice):
    def __init__(self, node):
        super().__init__(node)
        self.dev = devices.powermeter()
        self.dev.unsupported_attributes = ['devices']

    def update(self, event: Event):
        print(event)
